pub fn mutate(input: &mut Vec<u8>, seed: Option<u32>) -> usizeExpand description
This function mutates a buffer in-place
Arguments
input- A vector of bytes to mutate.seed- An optional seed value to pass to radamsa. If left as None it increments on each call from 0.
Return
usizerepresenting the number of filled bytes.
NOTE: Unlike generate mutated does not truncate the buffer to the returned size.